@@ -32,7 +32,11 @@
 #include "datatype/timestamp.h"
 #include "nodes/nodeFuncs.h"
 #include "optimizer/clauses.h"
-#include "optimizer/var.h"
+#if PG_VERSION_NUM < 120000
+	#include "optimizer/var.h"
+#else
+	#include "optimizer/optimizer.h"
+#endif
 #include "parser/parsetree.h"
 #include "utils/builtins.h"
 #include "utils/lsyscache.h"
@@ -87,7 +91,11 @@ static void deparseExpr(Expr *expr, deparse_expr_cxt *context);
 static void mysql_deparse_var(Var *node, deparse_expr_cxt *context);
 static void mysql_deparse_const(Const *node, deparse_expr_cxt *context);
 static void mysql_deparse_param(Param *node, deparse_expr_cxt *context);
+#if PG_VERSION_NUM < 120000
 static void mysql_deparse_array_ref(ArrayRef *node, deparse_expr_cxt *context);
+#else
+static void mysql_deparse_array_ref(SubscriptingRef *node, deparse_expr_cxt *context);
+#endif
 static void mysql_deparse_func_expr(FuncExpr *node, deparse_expr_cxt *context);
 static void mysql_deparse_op_expr(OpExpr *node, deparse_expr_cxt *context);
 static void mysql_deparse_operator_name(StringInfo buf, Form_pg_operator opform);
@@ -504,8 +512,13 @@ deparseExpr(Expr *node, deparse_expr_cxt *context)
 		case T_Param:
 			mysql_deparse_param((Param *) node, context);
 			break;
+#if PG_VERSION_NUM < 120000
 		case T_ArrayRef:
 			mysql_deparse_array_ref((ArrayRef *) node, context);
+#else
+		case T_SubscriptingRef:
+			mysql_deparse_array_ref((SubscriptingRef *) node, context);
+#endif
 			break;
 		case T_FuncExpr:
 			mysql_deparse_func_expr((FuncExpr *) node, context);
@@ -821,7 +834,11 @@ mysql_deparse_param(Param *node, deparse_expr_cxt *context)
  * Deparse an array subscript expression.
  */
 static void
+#if PG_VERSION_NUM < 120000
 mysql_deparse_array_ref(ArrayRef *node, deparse_expr_cxt *context)
+#else
+mysql_deparse_array_ref(SubscriptingRef *node, deparse_expr_cxt *context)
+#endif
 {
 	StringInfo	buf = context->buf;
 	ListCell   *lowlist_item;
@@ -1355,9 +1372,15 @@ foreign_expr_walker(Node *node,
 					state = FDW_COLLATE_UNSAFE;
 			}
 			break;
+#if PG_VERSION_NUM < 120000
 		case T_ArrayRef:
 			{
-				ArrayRef   *ar = (ArrayRef *) node;;
+				ArrayRef   *ar = (ArrayRef *) node;
+#else
+		case T_SubscriptingRef:
+			{
+				SubscriptingRef   *ar = (SubscriptingRef *) node;
+#endif
 
 				/* Assignment should not be in restrictions. */
 				if (ar->refassgnexpr != NULL)
