@@ -28,7 +28,12 @@
 #include "access/tupdesc.h"
 #include "foreign/foreign.h"
 #include "lib/stringinfo.h"
-#include "nodes/relation.h"
+#if PG_VERSION_NUM < 120000
+	#include "nodes/relation.h"
+#else
+	#include "nodes/pathnodes.h"
+#endif
+
 #include "utils/rel.h"
 
 #define MYSQL_PREFETCH_ROWS	100
